aboutsummaryrefslogtreecommitdiffstats
path: root/Source/SPTableContent.m
diff options
context:
space:
mode:
Diffstat (limited to 'Source/SPTableContent.m')
-rw-r--r--Source/SPTableContent.m3
1 files changed, 2 insertions, 1 deletions
diff --git a/Source/SPTableContent.m b/Source/SPTableContent.m
index 30329809..3285dc0f 100644
--- a/Source/SPTableContent.m
+++ b/Source/SPTableContent.m
@@ -1128,8 +1128,9 @@
[self storeCurrentDetailsForRestoration];
[self setViewportToRestore:NSZeroRect];
// Clear the table data column cache
[tableDataInstance resetColumnData];
+ [tableDataInstance resetStatusData];
// Load the table's data
[self loadTable:[tablesListInstance tableName]];
@@ -1128,8 +1128,9 @@
[self storeCurrentDetailsForRestoration];
[self setViewportToRestore:NSZeroRect];
- // Clear the table data column cache
+ // Clear the table data column cache and status (including counts)
[tableDataInstance resetColumnData];